==> HinemosWebClient_src-1.0.0.tar.gz: HinemosWebClient_src-1.0.0/js/common/formatterData.js <==
/*
 
Copyright (C) NEC Corporation 2012. All Rights Reserved. 
Copyright (C) NEC Soft, Ltd. 2012. All Rights Reserved. 
 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License 
as published by the Free Software Foundation, version 2.
 
This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied 
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE.  See the GNU General Public License for more details.
 
*/


/*******************************************************************************
 * Define values of HINEMOS data
 */
var getFormatterData = function(){
	return {
		confirmed  : ["${monitor.unconfirmed}", "${monitor.confirmed}"]
		,datetime  : "${js.format.datetime}"
		,job       : ["${jobunit}", "${jobnet}", "${job}", "${forward.file.job}"]
		,priority  : ["${critical}", "${unknown}", "${warning}", "${info}"]
		,run_status: {
			"0"   : "${wait}"         // TYPE_WAIT
			,"1"  : "${reserving}"    // TYPE_RESERVING
			,"2"  : "${skip}"         // TYPE_SKIP
			,"100": "${running}"      // TYPE_RUNNING
			,"101": "${stopping}"     // TYPE_STOPPING
			,"200": "${suspend}"      // TYPE_SUSPEND
			,"201": "${stop.at.once}" // TYPE_STOP
			,"300": "${end}"          // TYPE_END
			,"301": "${modified}"     // TYPE_MODIFIED
			,"400": "${start.error}"  // TYPE_ERROR
		}
		,end_status: ["${normal}", "${warning}", "${abnormal}", "${start}"]
		,valid     : ["${invalid}", "${valid}"]
		,wait_rule : ["${no}", "${yes}"]
	};
}

==> HinemosWebClient_src-2.0.1.tar.gz: HinemosWebClient_src-2.0.1/js/common/formatterData.js <==
/*
 
Copyright (C) NEC Corporation 2012. All Rights Reserved. 
Copyright (C) NEC Soft, Ltd. 2012. All Rights Reserved. 
 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License 
as published by the Free Software Foundation, version 2.
 
This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied 
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE.  See the GNU General Public License for more details.
 
*/


/*******************************************************************************
 * Define values of HINEMOS data
 */
var getFormatterData = function(){
	return {
		confirmed  : ["${monitor.unconfirmed}", "${monitor.confirmed}"]
		,updated  : {"false" : "${repository.agent.false}", "true" : "${repository.agent.true}"}
		,datetime  : "${js.format.datetime}"
		,job       : ["${jobunit}", "${jobnet}", "${job}", "${forward.file.job}"]
		,priority  : ["${critical}", "${unknown}", "${warning}", "${info}"]
		,run_status: {
			"0"   : "${wait}"         // TYPE_WAIT
			,"1"  : "${reserving}"    // TYPE_RESERVING
			,"2"  : "${skip}"         // TYPE_SKIP
			,"100": "${running}"      // TYPE_RUNNING
			,"101": "${stopping}"     // TYPE_STOPPING
			,"200": "${suspend}"      // TYPE_SUSPEND
			,"201": "${stop.at.once}" // TYPE_STOP
			,"300": "${end}"          // TYPE_END
			,"301": "${modified}"     // TYPE_MODIFIED
			,"400": "${start.error}"  // TYPE_ERROR
		}
		,end_status: ["${normal}", "${warning}", "${abnormal}", "${start}"]
		,valid     : ["${invalid}", "${valid}"]
		,wait_rule : ["${no}", "${yes}"]
		,trigger_type: {
			"1"  : "${trigger.schedule}"
			,"2" : "${trigger.manual}"
			,"3" : "${trigger.monitor}"
			,"-1": "${unknown}"
		}
	};
}
